cal.TasksByProject (Tasks) — amici1

# `cal.TasksByProject` (Tasks)

Detail fields

- `<Panel main_1 in lino.core.layouts.DetailLayout on lino_xl.lib.cal.ui.Tasks>`

- Short description (summary) : See `<django.db.models.fields.CharField: summary>`.

- Author (user) : The author of this object. A pointer to lino.modlib.users.models.User.

- `<Panel main_4 in lino.core.layouts.DetailLayout on lino_xl.lib.cal.ui.Tasks>`

- Description (description) : See `<lino.core.fields.RichTextField: description>`.

Actions

Filter parameters

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<lino.core.fields.DummyField object at 0x7fc81ce94b38>`

- `<lino.core.choicelists.ChoiceListField: state>`

## Filter parameters